#!/bin/bash

shellfu import pretty
shellfu import sfpi

shellfu import _jat_core

#
# Harness connector for JATS
#

#
# JATS harness plugin in use
#
_JATH=${_JATH:-none}

_jath__message() {
    #
    # Report message
    #
    # Usage:
    #     _jath__message ETYPE CASEID MESSAGE
    #
    #shellcheck disable=SC2030,SC2031
    (
        __jath__chdir
        export SFPI__PREFIX=_jathp
        export _JATH_CASEID=$2
        export _JATH_ETYPE=$1
        export _JATH_MESSAGE=$3
        sfpi__call "$_JATH" "message"
    )
}

_jath__phase() {
    #
    # Report phase start/end
    #
    # Usage:
    #     _jath__phase ETYPE CASEID HINT PTYPE PRESULT
    #
    #shellcheck disable=SC2030,SC2031
    (
        __jath__chdir
        export SFPI__PREFIX=_jathp
        export _JATH_ETYPE=$1
        export _JATH_CASEID=$2
        export _JATH_HINT=$3
        export _JATH_PTYPE=$4
        export _JATH_PRESULT=$5
        sfpi__call "$_JATH" "phase"
    )
}

_jath__relic() {
    #
    # Report phase start/end
    #
    # Usage:
    #     _jath__relic ETYPE CASEID RPATH HINT
    #
    #shellcheck disable=SC2030,SC2031
    (
        __jath__chdir
        export SFPI__PREFIX=_jathp
        export _JATH_ETYPE=$1
        export _JATH_CASEID=$2
        export _JATH_RPATH=$3
        export _JATH_HINT=$4
        sfpi__call "$_JATH" "relic"
    )
}

_jath__run() {
    #
    # Report run start/end
    #
    # Usage:
    #     _jath__run ETYPE CASEID FINALRESULT
    #
    #shellcheck disable=SC2030,SC2031
    (
        __jath__chdir
        export SFPI__PREFIX=_jathp
        export _JATH_ETYPE=$1
        export _JATH_CASEID=$2
        export _JATH_FINALRESULT=$3
        sfpi__call "$_JATH" "run"
    )
}

_jath__runstatus() {
    #
    # Report run status
    #
    # Usage:
    #     _jath__status running|completed|aborted
    #
    #shellcheck disable=SC2030,SC2031
    (
        __jath__chdir
        export SFPI__PREFIX=_jathp
        export _JATH_STATUS=$1
        sfpi__call "$_JATH" "runstatus"
    )
}

__jath__chdir() {
    #
    # Prepare jath dir and chdir there
    #
    local dir="$_JAT_CORE__RDIR/internal/jath/$_JATH"
    mkdir -p "$dir" || {
        die "could not create internal harness connector dir: $dir"
    }
    cd "$dir" || {
        die "could not chdir to internal harness connector dir: $dir"
    }
}

#shellfu module-version=0.2.12
