#!/bin/bash

shellfu import bkrh

shellfu import _jat_core

#
# Harness connector for JATS
#

#
# Run in singleton mode (JATS task owns beaker task)?
#
_JATHP_BKR__SINGLETON=${_JATHP_BKR__SINGLETON:-false}

___jathp_bkr__sanitize_pthel() {
    #
    # Sanitize $1 as result path element
    #
    tr -c '[:alnum:]_.+%@-' '-' <<<"$1" \
      | sed 's|^-*||; s|-*$||'
}

___jathp_bkr__sanitize_pth() {
    #
    # Sanitize $1 as result path
    #
    tr -c '[:alnum:]/_.+%@-' '-' <<<"$1" \
      | sed 's|^/*||; s|[/-]*$||'
}

_jathp_bkr__message() {
    #
    # Report message
    #
    # Usage:
    #     _JATH_CASEID=CASEID \
    #     _JATH_ETYPE=ETYPE \
    #     _JATH_MESSAGE=MESSAGE \
    #         _jathp_bkr__message
    #
    local cmd=()
    local word
    case $_JATH_ETYPE in
        MESSAGE.ERROR)   word="error" ;;
        MESSAGE.WARNING) word="warning" ;;
        *) return 0 ;;
    esac
    cmd=(
        bkrh__result \
            -p "$_JATH_CASEID!$word!" \
            -m "$_JATH_MESSAGE" \
            "$_JATH_RESULT"
    )
    debug -v cmd
    "${cmd[@]}"
}

_jathp_bkr__phase() {
    #
    # Report phase
    #
    # Usage:
    #     _JATH_CASEID=CASEID \
    #     _JATH_ETYPE=ETYPE \
    #     _JATH_HINT=HINT \
    #     _JATH_PTYPE=setup|test|diag|cleanup|none \
    #     _JATH_PRESULT=pass|fail|warning|error|none \
    #       _jathp_bkr__result
    #
    local cmd=()
    local path
    test "$_JATH_ETYPE" == PHASE.END || return 0
    path=$(___jathp_bkr__sanitize_pthel "$_JATH_HINT")
    test -n "$path" || path="$_JATH_CASEID#$_JATH_PTYPE"
    cmd=(
        bkrh__result \
            -p "$path" \
            "$_JATH_PRESULT"
    )
    debug -v cmd
    "${cmd[@]}"
}

_jathp_bkr__relic() {
    #
    # Report phase
    #
    # Usage:
    #     _JATH_CASEID=CASEID \
    #     _JATH_ETYPE=ETYPE \
    #     _JATH_RPATH=RPATH \
    #     _JATH_HINT=HINT \
    #         _jathp_bkr__relic
    #
    local rpath=$_JATH_RPATH
    local rroot=$_JAT_CORE__RDIR/relics
    local path=$rroot/$rpath
    local iname
    local ipath
    local cmd=()
    test -e "$path" || { warn "no such file: $path"; return 3; }
    find "$path" -type f \
      | while read -r ipath; do
            iname=$(___jathp_bkr__sanitize_pth "${ipath#"$rroot"}")
            cmd=(bkrh__log "$ipath" "$iname")
            debug -v cmd
            "${cmd[@]}"
        done
}

_jathp_bkr__run() {
    #
    # Report run event
    #
    # Usage:
    #     _JATH_CASEID=CASEID \
    #     _JATH_ETYPE=ETYPE \
    #     _JATH_FINALRESULT=FINALRESULT \
    #         _jathp_bkr__run
    #
    local cmd=()
    test "$_JATH_ETYPE" == RUN.END || return 0
    cmd=(
        bkrh__result \
            -p "$_JATH_CASEID#$_JATH_ETYPE" \
            "$_JATH_FINALRESULT"
    )
    debug -v cmd
    "${cmd[@]}"
}

_jathp_bkr__runstatus() {
    #
    # Report run status
    #
    # Usage:
    #     _JATH_STATUS=STATUS \
    #         _jathp_bkr__runstatus
    #
    return 0
}

#shellfu module-version=0.2.12
